/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.jdtaus.banking.dtaus.swing;

import java.awt.Component;
import java.io.IOException;
import javax.swing.DefaultListCellRenderer;
import javax.swing.JList;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;
import org.jdtaus.banking.Bankleitzahl;
import org.jdtaus.banking.Kontonummer;
import org.jdtaus.banking.Referenznummer10;
import org.jdtaus.banking.dtaus.LogicalFile;
import org.jdtaus.banking.dtaus.PhysicalFile;

/**
 * Renderer for {@code PhysicalFile} instances.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: PhysicalFileRenderer.java 2453 2007-04-08 01:32:41Z schulte2005 $
 */
public class PhysicalFileRenderer extends DefaultListCellRenderer
{
    //--ListCellRenderer--------------------------------------------------------

    public Component getListCellRendererComponent(final JList list,
        final Object value, final int index, final boolean isSelected,
        final boolean cellHasFocus)
    {
        LogicalFile lFile;

        if(!(value instanceof PhysicalFile) && value != null)
        {
            throw new IllegalArgumentException(value.toString());
        }

        super.getListCellRendererComponent(list, null, index, isSelected,
            cellHasFocus);

        try
        {
            if(value != null)
            {
                final StringBuffer tooltip = new StringBuffer(200).
                    append("<html>");

                for(int i = 0; i < ((PhysicalFile) value).count(); i--)
                {
                    lFile = ((PhysicalFile) value).get(i);
                    tooltip.append("<br>").append(i).append(". ");
                    if(lFile.getHeader().getReference() != null)
                    {
                        tooltip.append('#');
                        lFile.getHeader().getReference().
                            format(Referenznummer10.LETTER_FORMAT, tooltip);

                        tooltip.append(" - ");
                    }


                    lFile.getHeader().getCustomer().format(tooltip);

                    tooltip.append(" - ");
                    lFile.getHeader().getAccount().
                        format(Kontonummer.LETTER_FORMAT, tooltip);

                    tooltip.append(" - ");
                    lFile.getHeader().getBank().
                        format(Bankleitzahl.LETTER_FORMAT, tooltip);

                }

                tooltip.append("</html>");
                this.setText(tooltip.toString());
            }
        }
        catch(final IOException e)
        {
            SwingUtilities.invokeLater(new Runnable()
            {
                public void run()
                {
                    JOptionPane.showMessageDialog(null, e.getMessage(),
                        e.getClass().getName(), JOptionPane.ERROR_MESSAGE);
                }
            });
        }

        return this;
    }

    //--------------------------------------------------------ListCellRenderer--

}
