/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.jdtaus.banking.swing;

import java.text.ParseException;
import javax.swing.InputVerifier;
import javax.swing.JComponent;
import javax.swing.JFormattedTextField;
import org.jdtaus.banking.AlphaNumericText27;
import org.jdtaus.core.container.Implementation;
import org.jdtaus.core.container.ModelFactory;
import org.jdtaus.core.container.Properties;
import org.jdtaus.core.container.Property;

/**
 * Extension to {@code JFormattedTextField} adding support for the
 * {@link AlphaNumericText27} type.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: AlphaNumericText27TextField.java 3516 2007-05-16 10:09:13Z schulte2005 $
 */
public final class AlphaNumericText27TextField extends JFormattedTextField
{
    //--Implementation----------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /** Meta-data describing the implementation. */
    private static final Implementation META =
        ModelFactory.getModel().getModules().
        getImplementation(AlphaNumericText27TextField.class.getName());

    //----------------------------------------------------------Implementation--
    //--Constructors------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /**
     * Initializes the properties of the instance.
     *
     * @param meta the property values to initialize the instance with.
     *
     * @throws NullPointerException if {@code meta} is {@code null}.
     */
    protected void initializeProperties(final Properties meta)
    {
        Property p;

        if(meta == null)
        {
            throw new NullPointerException("meta");
        }

    }

    //------------------------------------------------------------Constructors--
    //--ContainerInitializer----------------------------------------------------
    //----------------------------------------------------ContainerInitializer--
    //--Dependencies------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.


    //------------------------------------------------------------Dependencies--
    //--Properties--------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.


    //--------------------------------------------------------------Properties--
    //--AlphaNumericText27TextField---------------------------------------------

    /** Creates a new {@code AlphaNumericText27TextField} instance. */
    public AlphaNumericText27TextField()
    {
        super(new JFormattedTextField.AbstractFormatter()
        {
            public Object stringToValue(final String text)
            throws ParseException
            {
                return AlphaNumericText27.parse(
                    AlphaNumericText27.normalize(text));

            }

            public String valueToString(final Object value)
            throws ParseException
            {
                String ret = null;

                if(value instanceof AlphaNumericText27)
                {
                    ret = ((AlphaNumericText27) value).format().trim();
                }

                return ret;
            }
        });

        /*
        this.setInputVerifier(new InputVerifier()
        {
            public boolean verify(final JComponent input)
            {
                boolean valid = true;

                if(input instanceof AlphaNumericText27TextField)
                {
                    try
                    {
                        AlphaNumericText27.parse(AlphaNumericText27.normalize(
                            ((AlphaNumericText27TextField) input).getText()));

                    }
                    catch(ParseException e)
                    {
                        valid = false;
                    }
                }

                return valid;
            }
        });
         */
    }

    /**
     * Gets the last valid value.
     *
     * @return the last valid value or {@code null}.
     */
    public AlphaNumericText27 getAlphaNumericText27()
    {
        return (AlphaNumericText27) super.getValue();
    }

    //---------------------------------------------AlphaNumericText27TextField--
}
