/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.jdtaus.banking.swing;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.text.ParseException;
import java.util.Locale;
import javax.swing.InputVerifier;
import javax.swing.JComponent;
import javax.swing.JFormattedTextField;
import org.jdtaus.banking.Bankleitzahl;
import org.jdtaus.banking.BankleitzahlInfo;
import org.jdtaus.banking.BankleitzahlenVerzeichnis;
import org.jdtaus.core.container.ContainerFactory;
import org.jdtaus.core.container.ContextFactory;
import org.jdtaus.core.container.ContextInitializer;
import org.jdtaus.core.container.Implementation;
import org.jdtaus.core.container.ModelFactory;
import org.jdtaus.core.container.Properties;
import org.jdtaus.core.container.Property;

/**
 * Extension to {@code JFormattedTextField} adding support for the
 * {@link Bankleitzahl} type.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: BankleitzahlTextField.java 3516 2007-05-16 10:09:13Z schulte2005 $
 */
public final class BankleitzahlTextField extends JFormattedTextField
{
    //--Implementation----------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /** Meta-data describing the implementation. */
    private static final Implementation META =
        ModelFactory.getModel().getModules().
        getImplementation(BankleitzahlTextField.class.getName());

    //----------------------------------------------------------Implementation--
    //--Constructors------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /**
     * Initializes the properties of the instance.
     *
     * @param meta the property values to initialize the instance with.
     *
     * @throws NullPointerException if {@code meta} is {@code null}.
     */
    protected void initializeProperties(final Properties meta)
    {
        Property p;

        if(meta == null)
        {
            throw new NullPointerException("meta");
        }

    }

    //------------------------------------------------------------Constructors--
    //--ContainerInitializer----------------------------------------------------
    //----------------------------------------------------ContainerInitializer--
    //--Dependencies------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /** Configured <code>BankleitzahlenVerzeichnis</code> implementation. */
    private transient BankleitzahlenVerzeichnis _dependency0;

    /**
     * Gets the configured <code>BankleitzahlenVerzeichnis</code> implementation.
     *
     * @return the configured <code>BankleitzahlenVerzeichnis</code> implementation.
     */
    private BankleitzahlenVerzeichnis getBankleitzahlenVerzeichnis()
    {
        BankleitzahlenVerzeichnis ret = null;
        if(this._dependency0 != null)
        {
            ret = this._dependency0;
        }
        else
        {
            ret = (BankleitzahlenVerzeichnis) ContainerFactory.getContainer().
                getDependency(BankleitzahlTextField.class,
                "BankleitzahlenVerzeichnis");

            if(ModelFactory.getModel().getModules().
                getImplementation(BankleitzahlTextField.class.getName()).
                getDependencies().getDependency("BankleitzahlenVerzeichnis").
                isBound())
            {
                this._dependency0 = ret;
            }
        }

        if(ret instanceof ContextInitializer && !((ContextInitializer) ret).
            isInitialized(ContextFactory.getContext()))
        {
            ((ContextInitializer) ret).initialize(ContextFactory.getContext());
        }

        return ret;
    }

    //------------------------------------------------------------Dependencies--
    //--Properties--------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.


    //--------------------------------------------------------------Properties--
    //--BankleitzahlTextField---------------------------------------------------

    /** Creates a new {@code BankleitzahlTextField} instance. */
    public BankleitzahlTextField()
    {
        super(new JFormattedTextField.AbstractFormatter()
        {
            public Object stringToValue(final String text)
            throws ParseException
            {
                return Bankleitzahl.parse(text);
            }

            public String valueToString(final Object value)
            throws ParseException
            {
                String ret = null;

                if(value instanceof Bankleitzahl)
                {
                    ret = ((Bankleitzahl) value).
                        format(Bankleitzahl.ELECTRONIC_FORMAT);

                }

                return ret;
            }
        });

        /*
        this.setInputVerifier(new InputVerifier()
        {
            public boolean verify(final JComponent input)
            {
                boolean valid = true;

                if(input instanceof BankleitzahlTextField)
                {
                    try
                    {
                        Bankleitzahl.parse(((BankleitzahlTextField) input).
                            getText());

                    }
                    catch(ParseException e)
                    {
                        valid = false;
                    }
                }

                return valid;
            }
        });
         */

        this.addPropertyChangeListener("value", new PropertyChangeListener()
        {
            public void propertyChange(final PropertyChangeEvent evt)
            {
                updateTooltip();
            }
        });
    }

    /**
     * Gets the last valid value.
     *
     * @return the last valid value or {@code null}.
     */
    public Bankleitzahl getBankleitzahl()
    {
        return (Bankleitzahl) super.getValue();
    }

    /**
     * Updates the component's tooltip to show information available for the
     * value returned by {@link #getValue()}.
     */
    protected void updateTooltip()
    {
        final Bankleitzahl blz = this.getBankleitzahl();

        if(blz != null)
        {
            final BankleitzahlInfo headOffice =
                this.getBankleitzahlenVerzeichnis().getHeadOffice(blz);

            if(headOffice != null)
            {
                final StringBuffer tooltip = new StringBuffer(200).
                    append("<html>");

                final NumberFormat plzFmt =
                    new DecimalFormat("00000");

                tooltip.append("<b>").append(headOffice.getName()).
                    append("</b><br>").append(headOffice.
                    getDescription()).append("<br>").append(
                    plzFmt.format(headOffice.getPostalCode())).
                    append(' ').append(headOffice.getCity()).append("</html>");

                this.setToolTipText(tooltip.toString());
            }
        }
    }

    //---------------------------------------------------BankleitzahlTextField--

}
