/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.jdtaus.editor;

import java.io.File;
import java.io.IOException;
import java.util.Locale;
import org.jdtaus.banking.dtaus.PhysicalFile;

/**
 * Formats a {@code PhysicalFile}.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: PhysicalFileFormatter.java 3156 2007-04-28 00:08:18Z schulte2005 $
 */
public interface PhysicalFileFormatter
{
    //--PhysicalFileFormatter---------------------------------------------------

    /**
     * Checks acceptance of a given file.
     *
     * @param file the file to check acceptance of.
     *
     * @return {@code true} if {@code file} is accepted by an implementation;
     * {@code false} if not.
     *
     * @throws NullPointerException if {@code file} is {@code null}.
     */
    boolean accept(File file);

    /**
     * Gets the description of the formatter.
     *
     * @param locale the locale to use for the description or {@code null} for
     * {@code Locale.getDefault()}.
     *
     * @return the description of the formatter.
     */
    String getDescription(Locale locale);

    /**
     * Formats the contents of {@code pFile} to {@code toFile}.
     *
     * @param pFile the physical file to format.
     * @param toFile the file to write the formatted content to.
     *
     * @throws NullPointerException if either {@code pFile} or {@code toFile}
     * {@code null}.
     * @throws IllegalArgumentException if ({@code accept(toFile)} is
     * {@code false}).
     * @throws IOException if writing fails.
     */
    void format(PhysicalFile pFile, File toFile)
    throws IOException;

    //---------------------------------------------------PhysicalFileFormatter--

}
